@@ -9,11 +9,12 @@
  * file that was distributed with this source code.
  */
 
+use PHPUnit\Framework\TestCase;
 use Seld\JsonLint\JsonParser;
 use Seld\JsonLint\ParsingException;
 use Seld\JsonLint\DuplicateKeyException;
 
-class JsonParserTest extends PHPUnit_Framework_TestCase
+class JsonParserTest extends TestCase
 {
     protected $json = array(
         '42', '42.3', '0.3', '-42', '-42.3', '-0.3',
@@ -32,6 +33,8 @@ class JsonParserTest extends PHPUnit_Framework_TestCase
         '["http:\/\/foo\\\\zomg"]',
         '{"":"foo"}',
         '{"a":"b", "b":"c"}',
+        '0',
+        '""',
     );
 
     /**
@@ -216,4 +219,12 @@ bar"}');
             $this->assertContains('BOM detected', $e->getMessage());
         }
     }
+
+    public function testLongString()
+    {
+        $parser = new JsonParser();
+
+        $json = '{"k":"' . str_repeat("a\\n",10000) . '"}';
+        $this->assertEquals(json_decode($json), $parser->parse($json));
+    }
 }
